@@ -1,6 +1,6 @@
 import asyncio
 
-from .types import TaskGroupError
+from .types import MultiError, TaskGroupError
 
 if hasattr(asyncio, 'TaskGroup'):
     from . import base
@@ -8,6 +8,7 @@ if hasattr(asyncio, 'TaskGroup'):
     from .base import *        # noqa
     from .persistent import *  # noqa
     __all__ = (
+        'MultiError',
         'TaskGroupError',
         *base.__all__,
         *persistent.__all__,
@@ -18,6 +19,7 @@ else:
     from .base_compat import *        # type: ignore  # noqa
     from .persistent_compat import *  # type: ignore  # noqa
     __all__ = (  # type: ignore
+        'MultiError',
         'TaskGroupError',
         *base_compat.__all__,
         *persistent_compat.__all__,
